@@ -1,8 +1,6 @@
 package Mojolicious::Plugin::RoutesAuthDBI::Admin;
 use Mojo::Base 'Mojolicious::Controller';
 use Mojolicious::Plugin::RoutesAuthDBI::PgSQL;#  sth cache
-use Exporter 'import'; 
-our @EXPORT_OK = qw(load_user validate_user);
 
 my $dbh; # one per class
 my $pkg = __PACKAGE__;
@@ -18,103 +16,61 @@ Mojolicious::Plugin::RoutesAuthDBI::Admin - is a mixed Mojolicious::Controller.
 
 =head1 SYNOPSIS
 
-In plugin:
-    
-    $conf->{access}{namespace} = 'Mojolicious::Plugin::RoutesAuthDBI';
-    $conf->{access}{controller} = 'Admin';
-    my $class  = join '::', $conf->{namespace}, ucfirst(lc($conf->{controller}));
-    require join '/', $conf->{access}{namespace} =~ s/::/\//gr, $conf->{access}{controller}.'.pm';# not use!
-    $class->import( qw(load_user validate_user) );
-    my $access = (bless $conf->{access}{access}, $module)->init_class;
-
-For routing:
-
-    $r->get('/myadmin')->over(<access>)->to('admin#index', namespace=>'Mojolicious::Plugin::RoutesAuthDBI',);
-
-=head1 OPTIONS for access controller
-
     $app->plugin('RoutesAuthDBI', 
         dbh => $app->dbh,
         auth => {...},
-        access => {< options below >},
+        access => {...},
+        admin => {< options below >},
     );
 
+
 =over 4
 
 =item * B<namespace> - default 'Mojolicious::Plugin::RoutesAuthDBI',
 
-=item * B<controller> - default 'Admin',
+=item * B<controller> - module controller name, default 'Admin',
 
-Both above options determining the module which will play as manager of authentication, accessing and generate routing from DBI source.
+Both above options determining the module controller for web actions on tables routes, roles, users and refs between them.
 
-=item * B<admin> - hashref: key I<prefix> => is prefix for admin urls of this module, key I<trust> => is a url subprefix for trust admin urls of this module. Optional.
+=item * B<prefix> -is a prefix for admin urls of this module. Default as name of controller lowcase.
 
-    admin = > {prefix=>'myadmin', trust => 'foooobaaar'},
+=item * B<trust> is a url subprefix for trust admin urls of this module. See defaults below.
 
-is admin urls like: /myadmin/foooobaaar/.....
+=back
 
-By default:
+=head2 Defaults
 
-    admin = > {prefix=>'admin', trust => $app->secrets->[0]},
+    admin = > {
+        namespace => 'Mojolicious::Plugin::RoutesAuthDBI',
+        module => 'Admin',
+        prefix => 'admin',
+        trust => $app->secrets->[0],
+    },
     
     admin = {}, # empty hashref sets defaults above
     
-    admin => undef, # disables routing of this module
+    admin => undef, # disables routing of admin controller
     
+    admin = > {prefix=>'myadmin', trust => 'foooobaaar'},# admin urls like: /myadmin/foooobaaar/.....
 
-=item * B<fail_auth_cb> = sub {my $c = shift;...}
-
-This callback invoke when request need auth route but authentication was failure.
-
-=item * B<fail_access_cb> = sub {my ($c, $route, $r_hash) = @_;...}
-
-This callback invoke when request need auth route but access was failure. $route - L<Mojolicious::Routes::Route> object, $r_hash - route hashref db item.
-
-=back
-
-=head1 EXPORT SUBS
-
-=over 4
-
-=item * B<load_user($c, $uid)> - fetch user record from table users by COOKIES. Import for Mojolicious::Plugin::Authentication. Required.
-
-=item * B<validate_user($c, $login, $pass, $extradata)> - fetch user record from table users by Mojolicious::Plugin::Authentication. Required.
-
-=back
 
 
 head1 METHODS NEEDS IN PLUGIN
 
 =over 4
 
-=item * B<init_class()> - make initialization of class vars: $dbh, $sql, $init_conf. Return $self object controller;
-
-=item * B<admin_routes()> - builtin this access controller routes. Return array of hashrefs. Depends on conf options I<prefix> and I<trust>. Optional method.
-
-=item * B<apply_route($self, $app, $r_hash)> - insert to app->routes an hash item $r_hash. Return new Mojolicious route;
-
-=item * B<table_routes()> - fetch records from table routes. Return arrayref of hashrefs records.
-
-=item * B<load_user_roles($self, $c, $uid)> - fetch records roles for auth user. Return hashref record.
-
-=item * B<access_route($self, $c, $id1, $id2)> - make check access to route by $id1 for user roles ids $id2 arrayref. Return false for deny access or true - allow access.
-
-=item * B<access_controller($self, $c, $r, $id2)> - make check access to route by special route record with request=NULL by $r->{namespace} and $r->{controller} for user roles ids $id2 arrayref. Return false for deny access or true - allow access to all actions of this controller.
+=item * B<self_routes()> - builtin this access controller routes. Return array of hashrefs. Depends on conf options I<prefix> and I<trust>.
 
 =back
 
 =cut
 
-######################## PLUGIN SPECIFIC! ##########################################
-
 sub init_class {# from plugin! init Class vars
 	my $c = shift;
 	my $args = {@_};
   $init_conf ||= $c;
-  if ($c->{admin}) {
-    $c->{admin}{prefix} =~ s/^\///;
-    $c->{admin}{trust} =~ s/\W/-/g;
-  }
+  $c->{prefix} =~ s/^\///;
+  $c->{trust} =~ s/\W/-/g;
 	$c->{dbh} ||= $dbh ||=  $args->{dbh};
 	$dbh ||= $c->{dbh};
 	$c->{sql} ||= $sql ||= $args->{sql} ||= bless [$dbh, {}], $c->{namespace}.'::PgSQL';#sth cache
@@ -123,66 +79,6 @@ sub init_class {# from plugin! init Class vars
 	return $c;
 }
 
-sub load_user {# import for Mojolicious::Plugin::Authentication
-	my ($c, $uid) = @_;
-	my $u = $dbh->selectrow_hashref($sql->sth('user/id'), undef, ($uid));
-  $c->app->log->debug("Loading user by id=$uid ". ($u ? 'success' : 'failed'));
-  return $u;
-}
-
-sub validate_user {# import for Mojolicious::Plugin::Authentication
-  my ($c, $login, $pass, $extradata) = @_;
-  if (my $u = $dbh->selectrow_hashref($sql->sth('user/login'), undef, ($login))) {
-    return $u->{id}
-      if $u->{pass} eq $pass  && !$u->{disable};
-  }
-  return undef;
-}
-
-sub apply_route {# meth in Plugin
-  my ($self, $app, $r_hash) = @_;
-  my $r = $app->routes;
-  return if $r_hash->{disable};
-  return unless $r_hash->{request};
-  my @request = grep /\S/, split /\s+/, $r_hash->{request}
-    or return;
-  my $nr = $r->route(pop @request);
-  $nr->via(@request) if @request;
-  
-  # STEP AUTH не катит! только один over!
-  #~ $nr->over(authenticated=>$r_hash->{auth});
-  # STEP ACCESS
-  $nr->over(access => $r_hash);
-  
-  $nr->to(controller=>$r_hash->{controller}, action => $r_hash->{action},  $r_hash->{namespace} ? (namespace => $r_hash->{namespace}) : (),);
-  $nr->name($r_hash->{name}) if $r_hash->{name};
-  #~ $app->log->debug("$pkg generate the route from data row [@{[$app->dumper($r_hash) =~ s/\n/ /gr]}]");
-  return $nr;
-}
-
-sub table_routes {
-  my ($self, $c, ) = @_;
-  $dbh->selectall_arrayref($sql->sth('all routes'), { Slice => {} },);
-}
-
-sub load_user_roles {
-	my ($self, $c, $uid) = @_;
-	$dbh->selectall_arrayref($sql->sth('user roles'), { Slice => {} }, ($uid));
-}
-
-sub access_route {
-	my ($self, $c, $id1, $id2,) = @_;
-	return scalar $dbh->selectrow_array($sql->sth('cnt refs'), undef, ($id1, $id2));
-}
-
-sub access_controller {
-	my ($self, $c, $r, $id2,) = @_;
-	return scalar $dbh->selectrow_array($sql->sth('access controller'), undef, ($r->{controller}, $r->{namespace},  $id2));
-}
-
-################################ END PLUGIN #################################
-
-
 
 sub index {
   my $c = shift;
@@ -193,7 +89,7 @@ $pkg
 You are signed as:
 @{[$c->dumper( $c->auth_user)]}
 
-@{[map "$_->{request}\t\t$_->{descr}\n", $c->admin_routes]}
+@{[map "$_->{request}\t\t$_->{descr}\n", $c->self_routes]}
 
 TXT
     and return
@@ -526,43 +422,44 @@ TXT
 }
 
 
-my @admin_routes_cols = qw(request namespace controller action name auth descr);
-sub admin_routes {# from plugin!
+my @self_routes_cols = qw(request namespace controller action name auth descr);
+sub self_routes {# from plugin!
   my $c = shift;
-  my $prefix = $init_conf->{admin}{prefix};
-  my $trust = $init_conf->{admin}{trust};
+  my $prefix = $init_conf->{prefix};
+  my $trust = $init_conf->{trust};
   my $ns = $init_conf->{namespace};
+  my $cntr = $init_conf->{controller};
 
   my $t = <<TABLE;
-/$prefix	$ns	admin	index	$prefix admin home	1	View main page
-/$prefix/role/new/:name	$ns	admin	new_role	$prefix create role	1	Add new role by :name
-/$prefix/role/del/:role/:user	$ns	admin	del_role_user	$prefix del ref role->user	1	Delete ref :user -> :role by user.id|user.login and role.id|role.name.
-/$prefix/role/dsbl/:role	$ns	admin	disable_role	$prefix disable role->user	1	Disable :role by role.id|role.name.
-/$prefix/role/enbl/:role	$ns	admin	enable_role	$prefix enable role->user	1	Enable :role by role.id|role.name.
-/$prefix/roles	$ns	admin	roles	$prefix view roles	1	View roles table
-/$prefix/roles/:user	$ns	admin	user_roles	$prefix roles of user	1	View roles of :user by id|login
-/$prefix/role/:role/:user	$ns	admin	new_role_user	$prefix create ref role->user	1	Assign :user to :role by user.id|user.login and role.id|role.name.
+/$prefix	$ns	$cntr	index	$prefix admin home	1	View main page
+/$prefix/role/new/:name	$ns	$cntr	new_role	$prefix create role	1	Add new role by :name
+/$prefix/role/del/:role/:user	$ns	$cntr	del_role_user	$prefix del ref role->user	1	Delete ref :user -> :role by user.id|user.login and role.id|role.name.
+/$prefix/role/dsbl/:role	$ns	$cntr	disable_role	$prefix disable role->user	1	Disable :role by role.id|role.name.
+/$prefix/role/enbl/:role	$ns	$cntr	enable_role	$prefix enable role->user	1	Enable :role by role.id|role.name.
+/$prefix/roles	$ns	$cntr	roles	$prefix view roles	1	View roles table
+/$prefix/roles/:user	$ns	$cntr	user_roles	$prefix roles of user	1	View roles of :user by id|login
+/$prefix/role/:role/:user	$ns	$cntr	new_role_user	$prefix create ref role->user	1	Assign :user to :role by user.id|user.login and role.id|role.name.
 
 
-/$prefix/route/new	$ns	admin	new_route	$prefix create route	1	Add new route by params: request,namespace, controller,....
-/$prefix/routes	$ns	admin	routes	$prefix view routes	1	View routes table
-/$prefix/routes/:role	$ns	admin	role_routes	$prefix routes of role	1	All routes of :role by id|name
-/$prefix/route/:route/:role	$ns	admin	ref	$prefix create ref route->role	1	Assign :route with :role by route.id and role.id|role.name
+/$prefix/route/new	$ns	$cntr	new_route	$prefix create route	1	Add new route by params: request,namespace, controller,....
+/$prefix/routes	$ns	$cntr	routes	$prefix view routes	1	View routes table
+/$prefix/routes/:role	$ns	$cntr	role_routes	$prefix routes of role	1	All routes of :role by id|name
+/$prefix/route/:route/:role	$ns	$cntr	ref	$prefix create ref route->role	1	Assign :route with :role by route.id and role.id|role.name
 
 
 
 
-/$prefix/user/new	$ns	admin	new_user	$prefix create user	1	Add new user by params: login,pass,...
-/$prefix/user/new/:login/:pass	$ns	admin	new_user	$prefix create user st	1	Add new user by :login & :pass
-/$prefix/users	$ns	admin	users	$prefix view users	1	View users table
-/$prefix/users/:role	$ns	admin	role_users	$prefix users of role	1	View users of :role by id|name
+/$prefix/user/new	$ns	$cntr	new_user	$prefix create user	1	Add new user by params: login,pass,...
+/$prefix/user/new/:login/:pass	$ns	$cntr	new_user	$prefix create user st	1	Add new user by :login & :pass
+/$prefix/users	$ns	$cntr	users	$prefix view users	1	View users table
+/$prefix/users/:role	$ns	$cntr	role_users	$prefix users of role	1	View users of :role by id|name
 
-get foo /sign/in	$ns	admin	sign	signin form	0	Login&pass form
-post /sign/in	$ns	admin	sign	signin params	0	Auth by params
-/sign/in/:login/:pass	$ns	admin	sign	signin stash	0	Auth by stash
-/sign/out	$ns	admin	signout	go away	1	Exit
+get foo /sign/in	$ns	$cntr	sign	signin form	0	Login&pass form
+post /sign/in	$ns	$cntr	sign	signin params	0	Auth by params
+/sign/in/:login/:pass	$ns	$cntr	sign	signin stash	0	Auth by stash
+/sign/out	$ns	$cntr	signout	go away	1	Exit
 
-/$prefix/$trust/user/new/:login/:pass	$ns	admin	trust_new_user	$prefix/$trust !trust create user!	0	Add new user by :login & :pass and auto assign to role 'Admin' and assign to access this controller!
+/$prefix/$trust/user/new/:login/:pass	$ns	$cntr	trust_new_user	$prefix/$trust !trust create user!	0	Add new user by :login & :pass and auto assign to role 'Admin' and assign to access this controller!
 
 TABLE
   
@@ -570,7 +467,7 @@ TABLE
   my @r = ();
   for my $line (grep /\S+/, split /\n/, $t) {
     my $r = {};
-    @$r{@admin_routes_cols} = map($_ eq '' ? undef : $_, split /\t/, $line);
+    @$r{@self_routes_cols} = map($_ eq '' ? undef : $_, split /\t/, $line);
     push @r, $r;
   }
   
@@ -585,14 +482,14 @@ sub routes000 {
   my $c = shift;
   
   $sth->{insert_routes} ||= $dbh->prepare(<<SQL);
-insert into routes (@{[join ',', @admin_routes_cols]}) values (@{[join ',', map '?', @admin_routes_cols]}) returning *;
+insert into routes (@{[join ',', @self_routes_cols]}) values (@{[join ',', map '?', @self_routes_cols]}) returning *;
 SQL
 
   local $dbh->{AutoCommit} = 0;
   #~ $dbh->begin_work;
   
     $c->render(format=>'txt', text=>"$pkg\n\n". $c->dumper([
-  map($dbh->selectrow_hashref($sth->{insert_routes}, undef, @$_{@admin_routes_cols},), $c->admin_routes)]).<<TXT);
+  map($dbh->selectrow_hashref($sth->{insert_routes}, undef, @$_{@self_routes_cols},), $c->self_routes)]).<<TXT);
 
 You must kill -HUP (reload/restart) your app! 
 
